==> google-cloud-bare-metal-solution-0.1.0.tar.gz: google-cloud-bare-metal-solution-0.1.0/google/cloud/bare_metal_solution_v2/services/bare_metal_solution/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core import operations_v1
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.bare_metal_solution_v2.types import baremetalsolution
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-bare-metal-solution",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class BareMetalSolutionTransport(abc.ABC):
    """Abstract transport class for BareMetalSolution."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "baremetalsolution.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """
        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_instances: gapic_v1.method.wrap_method(
                self.list_instances, default_timeout=None, client_info=client_info,
            ),
            self.get_instance: gapic_v1.method.wrap_method(
                self.get_instance, default_timeout=None, client_info=client_info,
            ),
            self.reset_instance: gapic_v1.method.wrap_method(
                self.reset_instance, default_timeout=None, client_info=client_info,
            ),
            self.list_volumes: gapic_v1.method.wrap_method(
                self.list_volumes, default_timeout=None, client_info=client_info,
            ),
            self.get_volume: gapic_v1.method.wrap_method(
                self.get_volume, default_timeout=None, client_info=client_info,
            ),
            self.update_volume: gapic_v1.method.wrap_method(
                self.update_volume, default_timeout=None, client_info=client_info,
            ),
            self.list_networks: gapic_v1.method.wrap_method(
                self.list_networks, default_timeout=None, client_info=client_info,
            ),
            self.get_network: gapic_v1.method.wrap_method(
                self.get_network, default_timeout=None, client_info=client_info,
            ),
            self.list_snapshot_schedule_policies: gapic_v1.method.wrap_method(
                self.list_snapshot_schedule_policies,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_snapshot_schedule_policy: gapic_v1.method.wrap_method(
                self.get_snapshot_schedule_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_snapshot_schedule_policy: gapic_v1.method.wrap_method(
                self.create_snapshot_schedule_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_snapshot_schedule_policy: gapic_v1.method.wrap_method(
                self.update_snapshot_schedule_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_snapshot_schedule_policy: gapic_v1.method.wrap_method(
                self.delete_snapshot_schedule_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_volume_snapshot: gapic_v1.method.wrap_method(
                self.create_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.restore_volume_snapshot: gapic_v1.method.wrap_method(
                self.restore_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_volume_snapshot: gapic_v1.method.wrap_method(
                self.delete_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_volume_snapshot: gapic_v1.method.wrap_method(
                self.get_volume_snapshot, default_timeout=None, client_info=client_info,
            ),
            self.list_volume_snapshots: gapic_v1.method.wrap_method(
                self.list_volume_snapshots,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_lun: gapic_v1.method.wrap_method(
                self.get_lun, default_timeout=None, client_info=client_info,
            ),
            self.list_luns: gapic_v1.method.wrap_method(
                self.list_luns, default_timeout=None, client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

       .. warning::
            Only call this method if the transport is NOT shared
            with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def list_instances(
        self,
    ) -> Callable[
        [baremetalsolution.ListInstancesRequest],
        Union[
            baremetalsolution.ListInstancesResponse,
            Awaitable[baremetalsolution.ListInstancesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_instance(
        self,
    ) -> Callable[
        [baremetalsolution.GetInstanceRequest],
        Union[baremetalsolution.Instance, Awaitable[baremetalsolution.Instance]],
    ]:
        raise NotImplementedError()

    @property
    def reset_instance(
        self,
    ) -> Callable[
        [baremetalsolution.ResetInstanceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_volumes(
        self,
    ) -> Callable[
        [baremetalsolution.ListVolumesRequest],
        Union[
            baremetalsolution.ListVolumesResponse,
            Awaitable[baremetalsolution.ListVolumesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_volume(
        self,
    ) -> Callable[
        [baremetalsolution.GetVolumeRequest],
        Union[baremetalsolution.Volume, Awaitable[baremetalsolution.Volume]],
    ]:
        raise NotImplementedError()

    @property
    def update_volume(
        self,
    ) -> Callable[
        [baremetalsolution.UpdateVolumeRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_networks(
        self,
    ) -> Callable[
        [baremetalsolution.ListNetworksRequest],
        Union[
            baremetalsolution.ListNetworksResponse,
            Awaitable[baremetalsolution.ListNetworksResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_network(
        self,
    ) -> Callable[
        [baremetalsolution.GetNetworkRequest],
        Union[baremetalsolution.Network, Awaitable[baremetalsolution.Network]],
    ]:
        raise NotImplementedError()

    @property
    def list_snapshot_schedule_policies(
        self,
    ) -> Callable[
        [baremetalsolution.ListSnapshotSchedulePoliciesRequest],
        Union[
            baremetalsolution.ListSnapshotSchedulePoliciesResponse,
            Awaitable[baremetalsolution.ListSnapshotSchedulePoliciesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_snapshot_schedule_policy(
        self,
    ) -> Callable[
        [baremetalsolution.GetSnapshotSchedulePolicyRequest],
        Union[
            baremetalsolution.SnapshotSchedulePolicy,
            Awaitable[baremetalsolution.SnapshotSchedulePolicy],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_snapshot_schedule_policy(
        self,
    ) -> Callable[
        [baremetalsolution.CreateSnapshotSchedulePolicyRequest],
        Union[
            baremetalsolution.SnapshotSchedulePolicy,
            Awaitable[baremetalsolution.SnapshotSchedulePolicy],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_snapshot_schedule_policy(
        self,
    ) -> Callable[
        [baremetalsolution.UpdateSnapshotSchedulePolicyRequest],
        Union[
            baremetalsolution.SnapshotSchedulePolicy,
            Awaitable[baremetalsolution.SnapshotSchedulePolicy],
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_snapshot_schedule_policy(
        self,
    ) -> Callable[
        [baremetalsolution.DeleteSnapshotSchedulePolicyRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def create_volume_snapshot(
        self,
    ) -> Callable[
        [baremetalsolution.CreateVolumeSnapshotRequest],
        Union[
            baremetalsolution.VolumeSnapshot,
            Awaitable[baremetalsolution.VolumeSnapshot],
        ],
    ]:
        raise NotImplementedError()

    @property
    def restore_volume_snapshot(
        self,
    ) -> Callable[
        [baremetalsolution.RestoreVolumeSnapshotRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_volume_snapshot(
        self,
    ) -> Callable[
        [baremetalsolution.DeleteVolumeSnapshotRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def get_volume_snapshot(
        self,
    ) -> Callable[
        [baremetalsolution.GetVolumeSnapshotRequest],
        Union[
            baremetalsolution.VolumeSnapshot,
            Awaitable[baremetalsolution.VolumeSnapshot],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_volume_snapshots(
        self,
    ) -> Callable[
        [baremetalsolution.ListVolumeSnapshotsRequest],
        Union[
            baremetalsolution.ListVolumeSnapshotsResponse,
            Awaitable[baremetalsolution.ListVolumeSnapshotsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_lun(
        self,
    ) -> Callable[
        [baremetalsolution.GetLunRequest],
        Union[baremetalsolution.Lun, Awaitable[baremetalsolution.Lun]],
    ]:
        raise NotImplementedError()

    @property
    def list_luns(
        self,
    ) -> Callable[
        [baremetalsolution.ListLunsRequest],
        Union[
            baremetalsolution.ListLunsResponse,
            Awaitable[baremetalsolution.ListLunsResponse],
        ],
    ]:
        raise NotImplementedError()


__all__ = ("BareMetalSolutionTransport",)

==> google-cloud-bare-metal-solution-1.0.0.tar.gz: google-cloud-bare-metal-solution-1.0.0/google/cloud/bare_metal_solution_v2/services/bare_metal_solution/transports/base.py <==
# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
import abc
from typing import Awaitable, Callable, Dict, Optional, Sequence, Union
import pkg_resources

import google.auth  # type: ignore
import google.api_core
from google.api_core import exceptions as core_exceptions
from google.api_core import gapic_v1
from google.api_core import retry as retries
from google.api_core import operations_v1
from google.auth import credentials as ga_credentials  # type: ignore
from google.oauth2 import service_account  # type: ignore

from google.cloud.bare_metal_solution_v2.types import baremetalsolution
from google.longrunning import operations_pb2  # type: ignore
from google.protobuf import empty_pb2  # type: ignore

try:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
        gapic_version=pkg_resources.get_distribution(
            "google-cloud-bare-metal-solution",
        ).version,
    )
except pkg_resources.DistributionNotFound:
    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()


class BareMetalSolutionTransport(abc.ABC):
    """Abstract transport class for BareMetalSolution."""

    AUTH_SCOPES = ("https://www.googleapis.com/auth/cloud-platform",)

    DEFAULT_HOST: str = "baremetalsolution.googleapis.com"

    def __init__(
        self,
        *,
        host: str = DEFAULT_HOST,
        credentials: ga_credentials.Credentials = None,
        credentials_file: Optional[str] = None,
        scopes: Optional[Sequence[str]] = None,
        quota_project_id: Optional[str] = None,
        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
        always_use_jwt_access: Optional[bool] = False,
        **kwargs,
    ) -> None:
        """Instantiate the transport.

        Args:
            host (Optional[str]):
                 The hostname to connect to.
            credentials (Optional[google.auth.credentials.Credentials]): The
                authorization credentials to attach to requests. These
                credentials identify the application to the service; if none
                are specified, the client will attempt to ascertain the
                credentials from the environment.
            credentials_file (Optional[str]): A file with credentials that can
                be loaded with :func:`google.auth.load_credentials_from_file`.
                This argument is mutually exclusive with credentials.
            scopes (Optional[Sequence[str]]): A list of scopes.
            quota_project_id (Optional[str]): An optional project to use for billing
                and quota.
            client_info (google.api_core.gapic_v1.client_info.ClientInfo):
                The client info used to send a user-agent string along with
                API requests. If ``None``, then default info will be used.
                Generally, you only need to set this if you're developing
                your own client library.
            always_use_jwt_access (Optional[bool]): Whether self signed JWT should
                be used for service account credentials.
        """

        # Save the hostname. Default to port 443 (HTTPS) if none is specified.
        if ":" not in host:
            host += ":443"
        self._host = host

        scopes_kwargs = {"scopes": scopes, "default_scopes": self.AUTH_SCOPES}

        # Save the scopes.
        self._scopes = scopes

        # If no credentials are provided, then determine the appropriate
        # defaults.
        if credentials and credentials_file:
            raise core_exceptions.DuplicateCredentialArgs(
                "'credentials_file' and 'credentials' are mutually exclusive"
            )

        if credentials_file is not None:
            credentials, _ = google.auth.load_credentials_from_file(
                credentials_file, **scopes_kwargs, quota_project_id=quota_project_id
            )
        elif credentials is None:
            credentials, _ = google.auth.default(
                **scopes_kwargs, quota_project_id=quota_project_id
            )

        # If the credentials are service account credentials, then always try to use self signed JWT.
        if (
            always_use_jwt_access
            and isinstance(credentials, service_account.Credentials)
            and hasattr(service_account.Credentials, "with_always_use_jwt_access")
        ):
            credentials = credentials.with_always_use_jwt_access(True)

        # Save the credentials.
        self._credentials = credentials

    def _prep_wrapped_messages(self, client_info):
        # Precompute the wrapped methods.
        self._wrapped_methods = {
            self.list_instances: gapic_v1.method.wrap_method(
                self.list_instances,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_instance: gapic_v1.method.wrap_method(
                self.get_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.reset_instance: gapic_v1.method.wrap_method(
                self.reset_instance,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_volumes: gapic_v1.method.wrap_method(
                self.list_volumes,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_volume: gapic_v1.method.wrap_method(
                self.get_volume,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_volume: gapic_v1.method.wrap_method(
                self.update_volume,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_networks: gapic_v1.method.wrap_method(
                self.list_networks,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_network: gapic_v1.method.wrap_method(
                self.get_network,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_snapshot_schedule_policies: gapic_v1.method.wrap_method(
                self.list_snapshot_schedule_policies,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_snapshot_schedule_policy: gapic_v1.method.wrap_method(
                self.get_snapshot_schedule_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_snapshot_schedule_policy: gapic_v1.method.wrap_method(
                self.create_snapshot_schedule_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.update_snapshot_schedule_policy: gapic_v1.method.wrap_method(
                self.update_snapshot_schedule_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_snapshot_schedule_policy: gapic_v1.method.wrap_method(
                self.delete_snapshot_schedule_policy,
                default_timeout=None,
                client_info=client_info,
            ),
            self.create_volume_snapshot: gapic_v1.method.wrap_method(
                self.create_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.restore_volume_snapshot: gapic_v1.method.wrap_method(
                self.restore_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.delete_volume_snapshot: gapic_v1.method.wrap_method(
                self.delete_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_volume_snapshot: gapic_v1.method.wrap_method(
                self.get_volume_snapshot,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_volume_snapshots: gapic_v1.method.wrap_method(
                self.list_volume_snapshots,
                default_timeout=None,
                client_info=client_info,
            ),
            self.get_lun: gapic_v1.method.wrap_method(
                self.get_lun,
                default_timeout=None,
                client_info=client_info,
            ),
            self.list_luns: gapic_v1.method.wrap_method(
                self.list_luns,
                default_timeout=None,
                client_info=client_info,
            ),
        }

    def close(self):
        """Closes resources associated with the transport.

        .. warning::
             Only call this method if the transport is NOT shared
             with other clients - this may cause errors in other clients!
        """
        raise NotImplementedError()

    @property
    def operations_client(self):
        """Return the client designed to process long-running operations."""
        raise NotImplementedError()

    @property
    def list_instances(
        self,
    ) -> Callable[
        [baremetalsolution.ListInstancesRequest],
        Union[
            baremetalsolution.ListInstancesResponse,
            Awaitable[baremetalsolution.ListInstancesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_instance(
        self,
    ) -> Callable[
        [baremetalsolution.GetInstanceRequest],
        Union[baremetalsolution.Instance, Awaitable[baremetalsolution.Instance]],
    ]:
        raise NotImplementedError()

    @property
    def reset_instance(
        self,
    ) -> Callable[
        [baremetalsolution.ResetInstanceRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_volumes(
        self,
    ) -> Callable[
        [baremetalsolution.ListVolumesRequest],
        Union[
            baremetalsolution.ListVolumesResponse,
            Awaitable[baremetalsolution.ListVolumesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_volume(
        self,
    ) -> Callable[
        [baremetalsolution.GetVolumeRequest],
        Union[baremetalsolution.Volume, Awaitable[baremetalsolution.Volume]],
    ]:
        raise NotImplementedError()

    @property
    def update_volume(
        self,
    ) -> Callable[
        [baremetalsolution.UpdateVolumeRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def list_networks(
        self,
    ) -> Callable[
        [baremetalsolution.ListNetworksRequest],
        Union[
            baremetalsolution.ListNetworksResponse,
            Awaitable[baremetalsolution.ListNetworksResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_network(
        self,
    ) -> Callable[
        [baremetalsolution.GetNetworkRequest],
        Union[baremetalsolution.Network, Awaitable[baremetalsolution.Network]],
    ]:
        raise NotImplementedError()

    @property
    def list_snapshot_schedule_policies(
        self,
    ) -> Callable[
        [baremetalsolution.ListSnapshotSchedulePoliciesRequest],
        Union[
            baremetalsolution.ListSnapshotSchedulePoliciesResponse,
            Awaitable[baremetalsolution.ListSnapshotSchedulePoliciesResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_snapshot_schedule_policy(
        self,
    ) -> Callable[
        [baremetalsolution.GetSnapshotSchedulePolicyRequest],
        Union[
            baremetalsolution.SnapshotSchedulePolicy,
            Awaitable[baremetalsolution.SnapshotSchedulePolicy],
        ],
    ]:
        raise NotImplementedError()

    @property
    def create_snapshot_schedule_policy(
        self,
    ) -> Callable[
        [baremetalsolution.CreateSnapshotSchedulePolicyRequest],
        Union[
            baremetalsolution.SnapshotSchedulePolicy,
            Awaitable[baremetalsolution.SnapshotSchedulePolicy],
        ],
    ]:
        raise NotImplementedError()

    @property
    def update_snapshot_schedule_policy(
        self,
    ) -> Callable[
        [baremetalsolution.UpdateSnapshotSchedulePolicyRequest],
        Union[
            baremetalsolution.SnapshotSchedulePolicy,
            Awaitable[baremetalsolution.SnapshotSchedulePolicy],
        ],
    ]:
        raise NotImplementedError()

    @property
    def delete_snapshot_schedule_policy(
        self,
    ) -> Callable[
        [baremetalsolution.DeleteSnapshotSchedulePolicyRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def create_volume_snapshot(
        self,
    ) -> Callable[
        [baremetalsolution.CreateVolumeSnapshotRequest],
        Union[
            baremetalsolution.VolumeSnapshot,
            Awaitable[baremetalsolution.VolumeSnapshot],
        ],
    ]:
        raise NotImplementedError()

    @property
    def restore_volume_snapshot(
        self,
    ) -> Callable[
        [baremetalsolution.RestoreVolumeSnapshotRequest],
        Union[operations_pb2.Operation, Awaitable[operations_pb2.Operation]],
    ]:
        raise NotImplementedError()

    @property
    def delete_volume_snapshot(
        self,
    ) -> Callable[
        [baremetalsolution.DeleteVolumeSnapshotRequest],
        Union[empty_pb2.Empty, Awaitable[empty_pb2.Empty]],
    ]:
        raise NotImplementedError()

    @property
    def get_volume_snapshot(
        self,
    ) -> Callable[
        [baremetalsolution.GetVolumeSnapshotRequest],
        Union[
            baremetalsolution.VolumeSnapshot,
            Awaitable[baremetalsolution.VolumeSnapshot],
        ],
    ]:
        raise NotImplementedError()

    @property
    def list_volume_snapshots(
        self,
    ) -> Callable[
        [baremetalsolution.ListVolumeSnapshotsRequest],
        Union[
            baremetalsolution.ListVolumeSnapshotsResponse,
            Awaitable[baremetalsolution.ListVolumeSnapshotsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def get_lun(
        self,
    ) -> Callable[
        [baremetalsolution.GetLunRequest],
        Union[baremetalsolution.Lun, Awaitable[baremetalsolution.Lun]],
    ]:
        raise NotImplementedError()

    @property
    def list_luns(
        self,
    ) -> Callable[
        [baremetalsolution.ListLunsRequest],
        Union[
            baremetalsolution.ListLunsResponse,
            Awaitable[baremetalsolution.ListLunsResponse],
        ],
    ]:
        raise NotImplementedError()

    @property
    def kind(self) -> str:
        raise NotImplementedError()


__all__ = ("BareMetalSolutionTransport",)
